modules/paint/types library
Classes
- QrEmbeddedImage
- The image data to embed (as an overlay) in the QR code. The image will
- QrEmbeddedImageStyle
- Styling options for any embedded image overlay
- QrImageOptionsData
- Styling options for data module.
- QrImageOptionsEye
- Styling options for finder pattern eye.
Enums
- FinderPatternPosition
- Enumeration representing the three finder pattern (square 'eye') locations.
- QrCodeElement
- Represents a specific element / part of a QR code. This is used to isolate the different parts so that we can style and modify specific parts independently.
- QrDataShape
- Enumeration representing the shape of Data modules inside QR.
- QrEyeShape
- Enumeration representing the finder pattern eye's shape.