QrImageOptionsIcon class

L'icône PI-SPI intégrée au centre du QR.

Constructors

QrImageOptionsIcon({ImageProvider<Object>? image, double size = 60})
Crée un label pour le QR code.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
image ImageProvider<Object>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited