PispiQrPayloadInputError enum
Codes d’erreurs liés à la validation des données lors de la génération d’un payload PI-SPI.
Ces erreurs concernent exclusivement les données d’entrée fournies par le développeur.
Values
- invalidAlias → const PispiQrPayloadInputError
-
Alias invalide (format incorrect, UUID invalide, etc.).
- invalidAmount → const PispiQrPayloadInputError
-
Montant invalide (format incorrect ou dépassement de longueur).
- invalidMerchantChannel → const PispiQrPayloadInputError
-
Canal marchand invalide ou incohérent avec le type de QR.
- invalidReferenceLabel → const PispiQrPayloadInputError
-
Reference label invalide (format ou longueur incorrecte).
- invalidQrType → const PispiQrPayloadInputError
-
Type de QR invalide (doit être static ou dynamic).
- invalidQrUser → const PispiQrPayloadInputError
-
Catégorie d’utilisateur invalide.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PispiQrPayloadInputError> - A constant List of the values in this enum, in order of their declaration.